---
title: Actionable language
description: Merchants use Shopify to get things done. Content should be written and structured to help them understand and take the most important actions.
icon: CircleRightMajor
keywords:
  - button content
  - button copy
  - button terminology
  - writing for buttons
  - link content
  - link copy
  - link terminology
  - writing for links
  - action words
  - calls to action
  - calls-to-action
  - CTA
  - verbs
  - copy instructions
  - copy rules
  - copy guidelines
  - content instructions
  - content rules
  - save
  - done
  - ok
  - okay
  - o.k.
  - accept
  - close
  - select
  - choose
  - edit
  - manage
  - change
  - switch
  - create
  - add
  - view
  - see
  - need
  - must
  - export
  - download
  - import
  - upload
  - confirmation modals
  - disruptive
  - delete
  - deletions
  - cancel
  - leave page
  - stay
  - discard
  - dangerous actions
  - risky actions
  - irreversible actions
  - confirmation alerts
  - warnings
  - confirmation messaging
  - headings
  - subheadings
  - titles
  - directional language
  - directionality
  - above
  - below
  - right
  - left
  - up
  - down
---

## Headings and subheadings

Headings and subheadings are titles and subtitles that refer to sections of the interface.

### Basic structure

Headings and subheadings should be:

**Informative and descriptive:**

- Highlight the most important concept or piece of information for merchants
- Help merchants understand what they’ll find in the section below

**Concise and scannable:**

- Use simple, clear language
- Keep headings to a single sentence
- Avoid using punctuation such as periods, commas, or semicolons
- Write in sentence case (capitalize the first word and proper nouns only)

<!-- dodont -->

#### Do

- Online store dashboard
- Custom reports
- Sell your products in person

#### Don’t

- This is your online store dashboard
- Custom Reports
- Sell your products in person!

<!-- end -->

### Articles

Whether or not to use articles (“the,” “a,” “an”) in headings and subheadings depends on the type of message.

#### Conversational headings

For more conversational areas of the product, like Home cards, sell pages, and empty states, use articles. It makes the language more approachable and helps people to understand new, complex concepts.

<!-- dodont -->

#### Do

- Secure your account with two-step authentication

#### Don’t

- Two-step authentication

<!-- end -->

#### Microcopy headings

For labels, titles, and microcopy, avoid articles to keep content short and actionable. This increases readability and encourages immediate action.

<!-- dodont -->

#### Do

- Create collection

#### Don’t

- Create a collection

<!-- end -->

---

## Sentences

Start sentences with imperative verbs when telling merchants what actions they can take (especially when introducing something new).

When a merchant reads a sentence that starts with an imperative verb it should sound like they’re being instructed what to do. Don’t use permissive language like “you can.”

<!-- dodont -->

#### Do

Add your first product and see how it looks in your store.

#### Don’t

- Products appear in your store after you add them.

- Add your first product so you can see how it looks in your store.

<!-- end -->

---

## Buttons

<!--- keywords: buttons, button copy, button text, button content, links, actions, calls to action, call to actions, action-led, action led, scannable, articles, choose , select, choose vs select, select vs choose, need, must, need vs must, must vs need -->

Buttons need to be clear and predictable. Merchants should be able to anticipate what will happen when they select a button. Never mislead someone by mislabeling a button.

Buttons should always lead with a strong verb that encourages action. To provide enough context to merchants, use the {verb} + {noun} content formula on buttons except in the case of common actions like “Done,” “Close,” “Cancel,” or “OK.”

<!-- dodont -->

#### Do

- Activate Apple Pay
- Explore free themes
- View shipping settings

#### Don’t

- Try Apple Pay
- Free themes
- Settings

<!-- end -->

Always write button text in sentence case, which means the first word is capitalized and the rest are lowercase (unless a term is a proper noun).

<!-- dodont -->

#### Do

- Buy new domain

#### Don’t

- Buy New Domain

<!-- end -->

Avoid unnecessary words and articles such as “the,” “an,” or “a.”

<!-- dodont -->

#### Do

Add menu item

#### Don’t

Add a menu item

<!-- end -->

---

## Links

Links need to be clear and predictable. Merchants should be able to anticipate what will happen when they select a link. Never mislead someone by mislabeling a link.

<!-- dodont -->

#### Do

- Get started with the
  [Ultimate Guide to Dropshipping](https://www.shopify.com/guides/dropshipping).

#### Don’t

- Want to learn more about dropshipping?
  [Click here](https://www.youtube.com/watch?v=dQw4w9WgXcQ).

<!-- end -->

Links should never use “click here” or “here” as link text.

### Links in a sentence

Links in full sentences shouldn’t link the entire sentence, only the text that describes where merchants go when they select the link.

It’s better for [internationalization](/foundations/internationalization) to have only single terms or small parts of phrases linked. Linking a full phrase is problematic because the word order might change, which would break the link into two parts.

<!-- dodont -->

#### Do

- Learn more about [Fraud Protect](https://www.shopify.com/fraud-protect).
- Manage the [channels](/) you use to sell products and services.

#### Don’t

- [Learn more about Fraud Protect](https://www.youtube.com/watch?v=dQw4w9WgXcQ).
- [Manage the channels](/) you use to sell products and services.

<!-- end -->

### Links outside of a sentence

Links that aren’t in full sentences should use the {verb + noun} pattern and not be punctuated, with the exception of question marks.

<!-- dodont -->

#### Do

- [Learn more](/)
- [Forgot password?](/)

#### Don’t

- [Learn more.](https://www.youtube.com/watch?v=dQw4w9WgXcQ)
- [Forgot password](/)

<!-- end -->

---

## Confirmations

Confirmations are presented for actions that can’t be undone or are difficult to undo.

Confirmation messages should:

- Always give merchants the option to either confirm or cancel their action
- Be used for a single, primary task
- Keep body content to one line of text and not use more than two calls to action

Confirmation titles should:

- Ask if merchants want to continue, using a concise {verb}+{noun} question
- Be one sentence and avoid using punctuation, with the exception of question marks
- Avoid articles (the, a, an) to keep content short and actionable
- Be written in sentence case (the first word is capitalized, and the rest is lowercase)

<!-- dodont -->

#### Do

- Discard unsaved changes?
- Delete 2 collections?
- Delete Dark Blue Tee?
- Leave page with unsaved changes?

#### Don’t

- Discard?
- Are you sure you want to delete?
- Are you sure you want to delete Dark Blue Tee?
- This page has unsaved changes are you sure you want to leave?

<!-- end -->

Confirmation body content should:

- Clearly explain if the action is irreversible or difficult to undo, using [plain language](https://polaris.shopify.com/content/product-content#write-for-a-grade-7-reading-level).
- Be concise: use only one line of text. Don’t start the sentence with “Are you sure?”

<!-- dodont -->

#### Do

- This can’t be undone.
- This will delete all edits since you last saved.
- Leaving this page will delete all unsaved changes.

#### Don’t

- Are you sure you want to delete the variant Dark Blue Tee/Small/Silk? This action cannot be reversed.
- If you discard changes, you’ll delete any edits you made since you last saved.
- If you leave this page, all unsaved changes will be lost. Are you sure you want to leave this page?

<!-- end -->

Confirmation primary and secondary actions should:

- Be clear and predictable: merchants should be able to anticipate what will happen when they click a button
- Scannable: avoid unnecessary words and articles such as “the,” “an,” or “a”

Since confirmation messages are placed in modals, the call to action in the title is in close context to the buttons. Because of this, the call to action text on the buttons doesn’t have to follow the {verb}+{noun} pattern. Instead, one word calls to action can be used, for example, [Cancel] \[Delete].

**Deletions**

Before merchants can delete objects like collections, transfers, products, and variants, we present them with a confirmation message that has two calls to action, one to [Cancel] and one to [Delete]. We keep it short and don’t use {verb}+{noun} button copy.

Primary action:

<!-- dodont -->

#### Do

- Delete

#### Don’t

- Remove
- Erase
- Discard

<!-- end -->

Secondary action:

<!-- dodont -->

#### Do

- Cancel

#### Don’t

- Discard

<!-- end -->

**Discarding changes while on a page**

Primary action:

<!-- dodont -->

#### Do

- Discard

#### Don’t

- Cancel

<!-- end -->

Secondary action:

<!-- dodont -->

#### Do

- Keep editing

#### Don’t

- Go back
- Cancel

<!-- end -->

**Leaving a page with unsaved changes**

Primary action:

<!-- dodont -->

#### Do

- Leave page

#### Don’t

- Exit
- Delete changes

<!-- end -->

Secondary action:

<!-- dodont -->

#### Do

- Stay

#### Don’t

- Go back
- Cancel
- Discard
- Keep editing

<!-- end -->

---

## Directional language

In the same way that links should never say “click here,” avoid using directional language such as “above/below” or “right/left.”

Directional language is confusing and unhelpful when spoken aloud by a screen reader. It creates challenges for internationalization (for example, right to left languages) and can conflict with mobile design patterns.

Directional language often indicates a lack of visual or content hierarchy. Whenever possible, keep instructional copy and related actions close together so that directional language isn’t needed.

---

## Save vs. done

Use “Save” when a change is saved immediately to a database and “Done” for [deferred saves](#deferred-saves).

### Saving immediately to a database

Use “Save” as the default for any action that saves immediately to a database.

#### Saving using the context bar component

When merchants make changes on a page they’re sometimes presented with a context bar at the top. This context bar displays a status message on the left to indicate the state of the changes, like “Unsaved discount.” Since the status message provides context around the action being taken, the button doesn’t need to follow the common {verb} + {noun} content formula. For example, [Save] instead of [Save product]. In the context bar component, use the verb “Save”.

<!-- dodont -->

#### Do

Use the verb “Save” in the context bar

![web context bar](/images/content/actionable-language/web-context-bar@2x.png)

#### Don’t

- Done
- Apply
- Save discount

<!-- end -->

Status messages in the context bar should be descriptive and follow the {adjective} + {noun} content formula.

<!-- dodont -->

#### Do

- Unsaved discount
- Unsaved product
- Unsaved customer
- Unsaved shipping zone

#### Don’t

- Unsaved changes

<!-- end -->

#### Saving in modals and sheets

Use the verb “Save” in modals and sheets when saving directly to the database.

<!-- dodont -->

#### Do

Use the verb “Save” in modals and sheets

![web save modal in edit state](/images/content/actionable-language/web-edit-save@2x.png)

#### Don’t

- Edit
- Done
- Apply

<!-- end -->

#### Saving at the bottom of a page

Use the {Save} + {noun} content formula when a save action doesn’t have the surrounding context of a modal or context bar. This applies to the save action at the bottom of pages.

For example, the action at the bottom of the Create discount page uses [Save discount]:

<!-- dodont -->

#### Do

![web save page action](/images/content/actionable-language/web-page-actions@2x.png)

#### Don’t

- Create discount
- Save
- Done
- Apply

<!-- end -->

### Deferred saves

Sometimes, when merchants confirm a set of changes inside a modal or sheet, these changes are applied as unsaved changes to the current page. In other words, the changes made weren’t immediately saved to the database. When this happens, don’t use the verb “Save” as the call to action because it would be misleading.

Use the adjective “Done” for deferred saves. When the modal or sheet closes, then merchants can save all of the changes they made.

Most deferred saves happen when confirming changes in Add, Edit, Manage, and Select modals and sheets.

<!-- dodont -->

#### Do

![deferred save modal with done button](/images/content/actionable-language/add-done@2x.png)

#### Don’t

- Add
- Edit
- Manage
- Select
- Apply
- Save

<!-- end -->

### Datepickers

Use the adjective “Done” for datepickers.

<!-- dodont -->

#### Do

![datepicker with done button](/images/content/actionable-language/datepicker@2x.png)

#### Don’t

- Apply
- Select
- Save

<!-- end -->

---

## OK vs. accept

Use the adjective “OK” when merchants need to confirm they’ve read something, but aren’t required to legally accept terms of service before continuing. For example, use “OK” when presenting a security notification in a modal or sheet.

<!-- dodont -->

#### Do

![modal with okay button spelled with capitalized letter O and K, no punctuation](/images/content/actionable-language/ok@2x.png)

#### Don’t

- Ok
- O.k.
- Okay
- Done
- Accept
- Continue

<!-- end -->

Use the adjective “Accept” when terms of service require legal confirmation before merchants can continue.

<!-- dodont -->

#### Do

Accept

#### Don’t

- Ok
- Done
- Continue

<!-- end -->

---

## Close vs. cancel

Use the back arrow button as the call to action for modals and screens when:

- the content is in a view-only state

Don’t use “Close” as the call to action when there’s the option for merchants to:

- make any changes to the modal or screen
- confirm they’ve read something or accept terms of service (see [OK vs. accept](#OK-accept))

<!-- dodont -->

#### Do

![web modal with close button](/images/content/actionable-language/web-close@2x.png)

#### Don’t

- Cancel
- Exit
- OK

<!-- end -->

Use “Cancel” as the option for merchants to back out of any changes made on a page, modal, or sheet. When the cancel button is pressed, changes automatically get discarded. “Cancel” is often paired with “Save” and “Done” actions (and is always placed to the left).

<!-- dodont -->

#### Do

Use the verb “Cancel” as the action for merchants to back out of changes

![web save modal in edit state](/images/content/actionable-language/web-edit-save@2x.png)

#### Don’t

- Exit
- Close
- Done

<!-- end -->

---

## Select vs. choose

Use the verb “select”:

- When telling merchants to pick something from a limited number of options of the same kind
- When merchants need to make an easy or obvious decision that doesn’t require deep reflection or analysis
- For defined lists and dropdown menus
- When merchants are given the option to pick from a list of already existing objects, like products

Pair Select modals and screens with the “Done” call to action.

<!-- dodont -->

#### Do

- Select your country of residence
- Select image
- Select countries

#### Don’t

- Select a pricing plan.
- Choose countries

<!-- end -->

Use the verb “choose” when:

- Encouraging merchants to make a decision that is more subjective, strategic, emotional, or open-ended
- Merchants have to pick from a large inventory of items, like themes, or options that require strategic decision making, like pricing plans

<!-- dodont -->

#### Do

- Choose a theme
- Choose a pricing plan.

#### Don’t

- Select a theme
- Select a pricing plan
- Choose a province.
- Pick a province.
- Pick a pricing plan.

<!-- end -->

---

## Edit vs. manage

Use the verb “edit” when you can change the input of a field (letters, numbers, properties). Place as link text next to the field or area that is being edited. There’s no need for a noun unless it’s unclear what’s being edited.

<!-- dodont -->

#### Do

- In this example, “Edit” is the correct call to action because it opens a modal where merchants update customer contact information ![modal where merchants can edit contact information](/images/content/actionable-language/edit-do@2x.png)
  Here are the editing actions that become available after the “Edit” button is selected ![modal where merchants can edit customer information](/images/content/actionable-language/edit-do2@2x.png)
- Edit an individual blog post

#### Don’t

- Use “Edit” if multiple actions can be taken after. “Manage” is more suitable.
- Modify

<!-- end -->

Use the verb “manage” at a higher level to convey that multiple actions can be done, or sections and settings can be updated. Pair this verb with a noun if it’s in a button or if it’s unclear what is being managed.

<!-- dodont -->

#### Do

- In this example, “Manage” is the correct call to action because it opens a modal where merchants can select channels to display their products ![manage button on the product page in the product availability section](/images/content/actionable-language/manage-do@2x.png)
  Here are the options that become available after the “Manage” button is selected ![modal where merchants can select sales channels](/images/content/actionable-language/manage-do2@2x.png)
- Manage multiple blog posts and comments

#### Don’t

- Edit
- Modify

<!-- end -->

---

## Change vs. switch

Use the verb “change” when merchants can replace an option, but not edit it. For example, they can change an image or theme, but the action doesn’t include editing its properties. Place as link text next to the field or area that is being changed. There’s no need for a noun unless it’s unclear what is being changed.

<!-- dodont -->

#### Do

- Change image ![change button at the bottom of the image display on the slideshow page of the theme editor](/images/content/actionable-language/change-do@2x.png)
  Here are the options that become available after the “Change” button is selected ![images library with an upload drop zone](/images/content/actionable-language/change-do2@2x.png)

#### Don’t

- Use the verb “change” if a selection must be made between only two options

<!-- end -->

Use the verb “switch” when it’s important for merchants to know what they’re switching between, like users, accounts, locations, or modes. When the switch happens, the previous option is turned off, logged out, or deactivated. Always pair with a noun to prevent confusion.

<!-- dodont -->

#### Do

- ![Title that says, switch from your third party provider to shopify payments, with a card below that says, payment processing rate of 2.4% plus 0.25 euros”](/images/content/actionable-language/switch-do@2x.png)
- ![Modal that says, switch locations to ‘new space’? You will only be able to sell inventory set to this location. Tax rates may also change. At the bottom there are two buttons. One says, cancel and one says, switch.](/images/content/actionable-language/switch-do2@2x.png)

#### Don’t

- Switch images

<!-- end -->

---

## Create vs. add

Use the verb “create” when you’re encouraging merchants to generate something from scratch, like a collection.

<!-- dodont -->

#### Do

- Create order
- Create collection
- Create discount

#### Don’t

- Add order
- Add collection
- Add discount

<!-- end -->

Use the verb “add” when you’re encouraging merchants to bring something that already exists into Shopify, like a product.

<!-- dodont -->

#### Do

- Add product
- Add customer

#### Don’t

- Create product
- Create customer

<!-- end -->

---

## View vs. see

Use the verb “view” when you’re encouraging merchants to go to a specific page or section for more details, or to reveal more information. Use “view” in buttons, calls to action, and link text.

<!-- dodont -->

#### Do

- View invoices
- View all {x}
- View details
- View report
- Try clearing your filters to view all results.

#### Don’t

- See invoices
- See all {x}
- See details
- See report

<!-- end -->

Use the verb “see” in more general, conversational descriptions without a specific call to action.

<!-- dodont -->

#### Do

- Add your first product and see how it looks on your store.
- Customers will see this name at checkout.

#### Don’t

- Add your first product and view how it looks on your store.
- Customers will view this name at checkout.

<!-- end -->

---

## Need vs. must

Use the verb “need” when you’re telling merchants something they’re required to do or should do.

<!-- dodont -->

#### Do

To buy a shipping label, you need to enter the total weight of your shipment, including packaging.

#### Don’t

To buy a shipping label, you must enter the total weight of your shipment, including packaging.

<!-- end -->

---

## Export vs. download

Use “export” as the call to action when merchants needs to transfer data from Shopify and convert it into a different format.

<!-- dodont -->

#### Do

- Export CSV file

#### Don’t

- Download CSV file

<!-- end -->

Use “download” as the call to action when merchants need to copy data (of the same format) from Shopify to a computer system.

<!-- dodont -->

#### Do

- Download shipping label
- Download PDF

#### Don’t

- Export shipping label
- Export PDF

<!-- end -->

---

## Import vs. upload

Use “import” as the call to action when merchants need to transfer data and convert it into a different format so it can be used in Shopify.

<!-- dodont -->

#### Do

- Import CSV file

#### Don’t

- Download CSV file

<!-- end -->

Use “upload” as the call to action when merchants need to copy data of the same format from a computer system into Shopify.

<!-- dodont -->

#### Do

- Upload image
- Upload file

#### Don’t

- Upload CSV file

<!-- end -->
